@@ -24,7 +24,6 @@ Engine class for CMU Pocket Sphinx
 
 import contextlib
 import locale
-import logging
 import os
 import wave
 
@@ -72,9 +71,6 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
         EngineBase.__init__(self)
         DelegateTimerManagerInterface.__init__(self)
 
-        # Set up the engine logger
-        logging.basicConfig()
-
         try:
             import sphinxwrapper, jsgf, pyaudio
         except ImportError as e:
@@ -674,8 +670,9 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
         )
 
         # Notify observers of failure.
+        results_obj = None  # TODO Use PS results object once implemented
         if not processing_occurred:
-            self._recognition_observer_manager.notify_failure()
+            self._recognition_observer_manager.notify_failure(results_obj)
 
         # Write the training data files if necessary.
         data_dir = self.config.TRAINING_DATA_DIR
@@ -741,11 +738,12 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
                 speech = speech.rstrip()  # remove trailing whitespace.
 
         # Notify observers if a keyphrase was matched.
+        results_obj = None  # TODO Use PS results object once implemented
         result = speech if speech in self._keyphrase_functions else ""
         words = tuple(result.split())
         if words:
             self._recognition_observer_manager.notify_recognition(
-                words, None, None
+                words, None, None, results_obj
             )
 
         # Call the registered function if there was a match and the function
@@ -763,13 +761,13 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
         # Notify observers after calling the keyphrase function.
         if words:
             self._recognition_observer_manager.notify_post_recognition(
-                words, None, None
+                words, None, None, results_obj
             )
 
         return result
 
     @classmethod
-    def _generate_words_rules(cls, words, mimicking):
+    def _generate_words_rules(cls, words, mimicking, all_dictation):
         # Convert words to Unicode, treat all uppercase words as dictation
         # words and other words as grammar words.
         # Minor note: this won't work for languages without capitalisation.
@@ -777,7 +775,7 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
         for word in words.split():
             if isinstance(word, binary_type):
                 word = word.decode(locale.getpreferredencoding())
-            if word.isupper() and mimicking:
+            if all_dictation or word.isupper() and mimicking:
                 # Convert dictation words to lowercase for consistent
                 # output.
                 result.append((word.lower(), 1000000))
@@ -806,6 +804,10 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
         hypotheses = {}
         wrappers = self._grammar_wrappers.copy().values()
 
+        # Save the LM hypothesis separately because it will almost always be favoured
+        # over grammar hypotheses.
+        lm_hypothesis = speech
+
         # Count exclusive grammars.
         exclusive_count = 0
         for wrapper in wrappers:
@@ -822,7 +824,6 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
 
         # No grammar has been loaded.
         if not wrappers:
-            # TODO What should we do here? Output formatted Dictation like DNS?
             return processing_occurred, speech
 
         # Batch process audio buffers for each active grammar. Store each
@@ -847,18 +848,28 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
 
         # Get the best hypothesis.
         speech = self._get_best_hypothesis(list(hypotheses.values()))
-        if not speech:
+        if not speech and not lm_hypothesis:
             return processing_occurred, speech
 
-        # Process speech using the first matching grammar.
-        words_rules = self._generate_words_rules(speech, mimicking)
-        for wrapper in wrappers:
-            if hypotheses[wrapper.search_name] != speech:
-                continue
+        if speech:
+            # Process speech using the first matching grammar.
+            words_rules = self._generate_words_rules(speech, mimicking, False)
+            for wrapper in wrappers:
+                if hypotheses[wrapper.search_name] != speech:
+                    continue
 
-            processing_occurred = wrapper.process_words(words_rules)
-            if processing_occurred:
-                break
+                processing_occurred = wrapper.process_words(words_rules)
+                if processing_occurred:
+                    break
+
+        if not processing_occurred:
+            # Process grammars using the LM hypothesis as dictation words.
+            dictation_words = self._generate_words_rules(lm_hypothesis, mimicking,
+                                                         True)
+            for wrapper in wrappers:
+                processing_occurred = wrapper.process_words(dictation_words)
+                if processing_occurred:
+                    break
 
         # Return whether processing occurred and the final speech hypothesis for
         # post processing.
@@ -1066,6 +1077,9 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
     def _get_language(self):
         return self.config.LANGUAGE
 
+    def _has_quoted_words_support(self):
+        return False
+
     # ----------------------------------------------------------------------
     # Training-related methods
 
@@ -1186,9 +1200,12 @@ class SphinxEngine(EngineBase, DelegateTimerManagerInterface):
         # Notify observers about recognition resume.
         keyphrase = self.config.WAKE_PHRASE
         words = tuple(keyphrase.strip().split())
+        results_obj = None  # TODO Use PS results object once implemented
         if words and notify:
-            self._recognition_observer_manager.notify_recognition(words, None, None)
-            self._recognition_observer_manager.notify_post_recognition(words, None, None)
+            manager = self._recognition_observer_manager
+            arguments = (words, None, None, results_obj)
+            manager.notify_recognition(*arguments)
+            manager.notify_post_recognition(*arguments)
 
         # Restore the callbacks to normal
         def hypothesis(hyp):
